Crate libtest2_mimic

An experimental replacement for libtest-mimic

Usage

To use this, you most likely want to add a manual [[test]] section to Cargo.toml and set harness = false. For example:

[[test]]
name = "mytest"
path = "tests/mytest.rs"
harness = false

And in tests/mytest.rs you would call Harness::main in the main function:

libtest2_mimic::Harness::with_env()
    .main();

Structs

Harness
RunError
State
Trial

Enums

TestKind
Type of the test according to the rust book conventions.

Type Aliases

RunResult